# Configuration API

::: pretok.config.PretokConfig

::: pretok.config.PipelineConfig

::: pretok.config.DetectionConfig

::: pretok.config.TranslationConfig

::: pretok.config.LLMTranslatorConfig

::: pretok.config.CacheConfig

::: pretok.config.SegmentConfig

::: pretok.config.load_config

::: pretok.config.ConfigurationError
